@@ -1,4 +1,4 @@
-import helpers.setup
+from helpers import settings
 from pathlib import Path
 
 
@@ -6,9 +6,9 @@ def get_trains():
     """
     Returns TRAINS that are not excluded
     """
-    if Path(setup.TRAINS_PATH).exists():
+    if Path(settings.TRAINS_PATH).exists():
         trains = [train for train in Path(
-            setup.TRAINS_PATH).iterdir() if train.stem not in setup.EXCLUDE_TRAINS]
+            settings.TRAINS_PATH).iterdir() if train.stem not in settings.EXCLUDE_TRAINS]
 
     return trains
 
@@ -18,7 +18,7 @@ def get_apps(train):
     Returns APPS that are nto excluded
     """
     apps = [app for app in Path(train).iterdir()
-            if app.stem not in setup.EXCLUDE_APPS]
+            if app.stem not in settings.EXCLUDE_APPS]
 
     return apps
 
@@ -29,8 +29,8 @@ def get_ordered_trains(trains):
     """
     # Convert list variable to list of Paths
     train_order = [
-        Path(setup.TRAINS_PATH, train)
-        for train in setup.TRAIN_ORDER_FOR_FILES
+        Path(settings.TRAINS_PATH, train)
+        for train in settings.TRAIN_ORDER_FOR_FILES
     ]
     # Add trains from config variable that also exists in the actual trains
     ordered_trains = [
